==> hestia_logger-0.1.0.tar.gz: hestia_logger-0.1.0/hestia_logger/decorators/decorators.py <==
import functools
import time
import asyncio
import json
import inspect
import traceback
from hestia_logger.core.custom_logger import get_logger

SENSITIVE_KEYS = {"password", "token", "secret", "apikey", "api_key"}


def mask_sensitive_data(kwargs):
    """Masks sensitive data in function arguments."""
    return {
        key: "***" if key.lower() in SENSITIVE_KEYS else value
        for key, value in kwargs.items()
    }


def sanitize_module_name(module_name):
    """Converts "__module__" format to "module_module" for cleaner log file names."""
    if module_name.startswith("__") and module_name.endswith("__"):
        return f"{module_name.strip('_')}"
    return module_name


def safe_serialize(obj):
    """Safely serialize objects to JSON, handling non-serializable cases."""
    try:
        return json.dumps(obj, ensure_ascii=False)
    except TypeError:
        return str(obj)  # Fallback for non-serializable objects


def log_execution(func=None, *, logger_name=None):
    if func is None:
        return lambda f: log_execution(f, logger_name=logger_name)

    module_name = func.__module__
    sanitized_name = sanitize_module_name(module_name)
    service_logger = get_logger(logger_name or sanitized_name)
    app_logger = get_logger("app", internal=True)

    if asyncio.iscoroutinefunction(func):

        @functools.wraps(func)
        async def async_wrapper(*args, **kwargs):
            start_time = time.time()
            # Include positional arguments in kwargs for masking
            args_names = inspect.signature(func).parameters.keys()
            all_kwargs = {**dict(zip(args_names, args)), **kwargs}
            sanitized_kwargs = mask_sensitive_data(all_kwargs)
            log_entry = {
                "timestamp": time.strftime("%Y-%m-%dT%H:%M:%S.Z", time.gmtime()),
                "service": service_logger.name,
                "function": func.__name__,
                "status": "started",
                "args": safe_serialize(args),
                "kwargs": safe_serialize(sanitized_kwargs),
            }
            app_logger.info(json.dumps(log_entry, ensure_ascii=False))
            service_logger.info(f"📌 Started: {func.__name__}()")
            try:
                result = await func(*args, **kwargs)
                duration = time.time() - start_time
                log_entry.update(
                    {
                        "status": "completed",
                        "duration": f"{duration:.4f} sec",
                        "result": safe_serialize(result),
                    }
                )
                app_logger.info(json.dumps(log_entry, ensure_ascii=False))
                service_logger.info(
                    f"✅ Finished: {func.__name__}() in {duration:.4f} sec"
                )
                return result
            except Exception as e:
                log_entry.update(
                    {
                        "status": "error",
                        "error": str(e),
                        "traceback": traceback.format_exc(),
                    }
                )
                app_logger.error(json.dumps(log_entry, ensure_ascii=False))
                service_logger.error(f"❌ Error in {func.__name__}: {e}")
                raise

        return async_wrapper
    else:

        @functools.wraps(func)
        def sync_wrapper(*args, **kwargs):
            start_time = time.time()
            sanitized_kwargs = mask_sensitive_data(kwargs)
            log_entry = {
                "timestamp": time.strftime("%Y-%m-%dT%H:%M:%S.Z", time.gmtime()),
                "service": service_logger.name,
                "function": func.__name__,
                "status": "started",
                "args": safe_serialize(args),
                "kwargs": safe_serialize(sanitized_kwargs),
            }
            app_logger.info(json.dumps(log_entry, ensure_ascii=False))
            service_logger.info(f"📌 Started: {func.__name__}()")
            try:
                result = func(*args, **kwargs)
                duration = time.time() - start_time
                log_entry.update(
                    {
                        "status": "completed",
                        "duration": f"{duration:.4f} sec",
                        "result": safe_serialize(result),
                    }
                )
                app_logger.info(json.dumps(log_entry, ensure_ascii=False))
                service_logger.info(
                    f"✅ Finished: {func.__name__}() in {duration:.4f} sec"
                )
                return result
            except Exception as e:
                log_entry.update(
                    {
                        "status": "error",
                        "error": str(e),
                        "traceback": traceback.format_exc(),
                    }
                )
                app_logger.error(json.dumps(log_entry, ensure_ascii=False))
                service_logger.error(f"❌ Error in {func.__name__}: {e}")
                raise

        return sync_wrapper

==> hestia_logger-1.1.0.tar.gz: hestia_logger-1.1.0/hestia_logger/decorators/decorators.py <==
import functools
import time
import sys
import asyncio
import json
import inspect
import traceback
import os
from hestia_logger.core.custom_logger import get_logger

SENSITIVE_KEYS = {"password", "token", "secret", "apikey", "api_key", "credential"}


def mask_sensitive_data(kwargs):
    return {
        key: "***" if key.lower() in SENSITIVE_KEYS else value
        for key, value in kwargs.items()
    }


def safe_serialize(obj):
    try:
        return json.dumps(obj, ensure_ascii=False)
    except TypeError:
        return str(obj)


def get_caller_script_name():
    """Returns the filename of the script that called the decorated function,
    while handling pytest execution correctly."""
    stack = inspect.stack()

    for frame in reversed(stack):  # Traverse the call stack from the outermost call
        script_path = frame.filename
        if "pytest" not in script_path:  # Ignore pytest internals
            script_name = os.path.basename(script_path).replace(".py", "")
            return script_name

    return "unknown_script"


def log_execution(func=None, *, logger_name=None):
    if func is None:
        return lambda f: log_execution(f, logger_name=logger_name)

    # Use the actual script filename instead of "__main__"
    caller_script_name = get_caller_script_name()
    service_logger = get_logger(logger_name or caller_script_name)
    app_logger = get_logger("app", internal=True)

    if asyncio.iscoroutinefunction(func):

        @functools.wraps(func)
        async def async_wrapper(*args, **kwargs):
            start_time = time.time()
            sanitized_kwargs = mask_sensitive_data(kwargs)

            log_entry = {
                "timestamp": time.strftime("%Y-%m-%dT%H:%M:%S.Z", time.gmtime()),
                "service": service_logger.name,
                "function": func.__name__,
                "status": "started",
                "args": safe_serialize(args),
                "kwargs": safe_serialize(sanitized_kwargs),
            }

            app_logger.info(json.dumps(log_entry, ensure_ascii=False))
            service_logger.info(f"📌 Started: {func.__name__}()")

            try:
                result = await func(*args, **kwargs)
                duration = time.time() - start_time

                log_entry.update(
                    {
                        "status": "completed",
                        "duration": f"{duration:.4f} sec",
                        "result": safe_serialize(result),
                    }
                )

                app_logger.info(json.dumps(log_entry, ensure_ascii=False))
                service_logger.info(
                    f"✅ Finished: {func.__name__}() in {duration:.4f} sec"
                )

                return result
            except Exception as e:
                log_entry.update(
                    {
                        "status": "error",
                        "error": str(e),
                        "traceback": traceback.format_exc(),
                    }
                )

                app_logger.error(json.dumps(log_entry, ensure_ascii=False))
                service_logger.error(f"❌ Error in {func.__name__}: {e}")

                raise

        return async_wrapper
    else:

        @functools.wraps(func)
        def sync_wrapper(*args, **kwargs):
            start_time = time.time()
            sanitized_kwargs = mask_sensitive_data(kwargs)

            log_entry = {
                "timestamp": time.strftime("%Y-%m-%dT%H:%M:%S.Z", time.gmtime()),
                "service": service_logger.name,
                "function": func.__name__,
                "status": "started",
                "args": safe_serialize(args),
                "kwargs": safe_serialize(sanitized_kwargs),
            }

            app_logger.info(json.dumps(log_entry, ensure_ascii=False))
            service_logger.info(f"📌 Started: {func.__name__}()")

            try:
                result = func(*args, **kwargs)
                duration = time.time() - start_time

                log_entry.update(
                    {
                        "status": "completed",
                        "duration": f"{duration:.4f} sec",
                        "result": safe_serialize(result),
                    }
                )

                app_logger.info(json.dumps(log_entry, ensure_ascii=False))
                service_logger.info(
                    f"✅ Finished: {func.__name__}() in {duration:.4f} sec"
                )

                return result

            except Exception as e:
                exc_type, exc_value, exc_tb = sys.exc_info()
                tb_summary = traceback.extract_tb(exc_tb)
                last_call = tb_summary[-1] if tb_summary else None

                error_location = {
                    "filename": last_call.filename if last_call else None,
                    "line": last_call.lineno if last_call else None,
                    "function": last_call.name if last_call else func.__name__,
                }

                log_entry.update(
                    {
                        "status": "error",
                        "error": str(e),
                        "traceback": traceback.format_exc(),
                        "location": error_location,
                    }
                )

                app_logger.error(json.dumps(log_entry, ensure_ascii=False))
                service_logger.error(
                    f"❌ Error in {error_location['function']} at {error_location['filename']}:{error_location['line']} – {e}"
                )

                raise

        return sync_wrapper
